get_ubioid(searchterm, searchtype = "scientific", ask = TRUE,
verbose = TRUE, rows = NA, family = NULL, rank = NULL, ...)as.ubioid(x, check = TRUE)
## S3 method for class 'ubioid':
as.ubioid(x, check = TRUE)
## S3 method for class 'character':
as.ubioid(x, check = TRUE)
## S3 method for class 'list':
as.ubioid(x, check = TRUE)
## S3 method for class 'numeric':
as.ubioid(x, check = TRUE)
## S3 method for class 'data.frame':
as.ubioid(x, check = TRUE)
## S3 method for class 'ubioid':
as.data.frame(x, ...)
get_ubioid_(searchterm, verbose = TRUE, searchtype = "scientific",
rows = NA)
get_ubioid_Filtering below.rank_ref for possible
options. Though note that some data sources use atypical ranks, so inspect the
data itself for options. Optional. See Filtering belas.ubioidas.ubioidfamily and rank are not used in the search to the data
provider, but are used in filtering the data down to a subset that is closer to the
target you want. For all these parameters,
you can use regex strings since we use grep internally to match.
Filtering narrows down to the set that matches your query, and removes the rest.get_uid, ubio_search