Learn R Programming

taxize (version 0.3.0)

gettsnfromlsid: Gets the TSN corresponding to the LSID, or an empty result if there is no match.

Description

Gets the TSN corresponding to the LSID, or an empty result if there is no match.

Usage

gettsnfromlsid(lsid = NA, curlopts = list(), curl = getCurlHandle(),
  verbose = TRUE)

Arguments

lsid
lsid for a taxonomic group (numeric)
curlopts
optional additional curl options (debugging tools mostly)
curl
If using in a loop, call getCurlHandle() first and pass the returned value in here (avoids unnecessary footprint)
verbose
(logical) Print messages or not. Default to TRUE.

Examples

Run this code
gettsnfromlsid(lsid = "urn:lsid:itis.gov:itis_tsn:28726")
gettsnfromlsid(lsid = "urn:lsid:itis.gov:itis_tsn:0")

Run the code above in your browser using DataLab