Learn R Programming

taxize (version 0.0.2)

phylomatic_tree: Format tree string, submit to Phylomatic, get newick tree.

Description

Format tree string, submit to Phylomatic, get newick tree.

Usage

phylomatic_tree(x, get, format, retphylo = TRUE,
    url = "http://phylodiversity.net/phylomatic/pm/phylomatic.cgi")

Arguments

x
Phylomatic format input.
get
'GET' or 'POST' format for submission to the website.
format
Newick (new) or xml (xml) output.
retphylo
Return phylo tree object (TRUE or FALSE).
url
The base URL for the Phylomatic API service, leave as is.

Value

  • Newick formatted tree.

Details

Submitted in POST format (not GET format). Version: already have in Phylomatic input format forward slash (/ ->

Examples

Run this code
dat_ <- laply(list("36616", "19322", "183327"), itis_phymat_format, format='rsubmit')
tree <- phylomatic_tree(dat_, 'GET', 'new', 'TRUE')
plot(tree)

Run the code above in your browser using DataLab