ncbi_getbyname: This function is deprecated and will be removed in a future
version of this package.ncbi_getbyid: This function is deprecated and will be removed in a future
version of this package.ncbi_search: This function is deprecated and will be removed in a future
version of this package.phylomatic_tree: This function is deprecated and will be removed in a future
version of this package.eol_invasive: This function is deprecated and will be removed in a future
version of this package.gisd_isinvasive: This function is deprecated and will be removed in a future
version of this package.All of the above functions will be available in an R package in development called traits