powered by
Get The Plant List families.
tpl_families(...)
Returns a data.frame including the names of all families indexed by The Plant List, and the major groups into which they fall (i.e. Angiosperms, Gymnosperms, Bryophytes and Pteridophytes).
data.frame
(list) Curl options passed on to crul::verb-GET
John Baumgartner ([email protected])
Requires an internet connection in order to connect to <www.theplantlist.org>.
tpl_get()
if (FALSE) { # Get a data.frame of plant families, with the group name # (Angiosperms, etc.) head(tpl_families()) }
Run the code above in your browser using DataLab