Get a IUCN Redlist taxon
get_iucn(sci, messages = TRUE, key = NULL, x = NULL, ...)
as.iucn(x, check = TRUE, key = NULL)
# S3 method for class 'iucn'
as.iucn(x, check = TRUE, key = NULL)
# S3 method for class 'character'
as.iucn(x, check = TRUE, key = NULL)
# S3 method for class 'list'
as.iucn(x, check = TRUE, key = NULL)
# S3 method for class 'numeric'
as.iucn(x, check = TRUE, key = NULL)
# S3 method for class 'data.frame'
as.iucn(x, check = TRUE, key = NULL)
# S3 method for class 'iucn'
as.data.frame(x, ...)(character) A vector of scientific names. Or, a
taxon_state object (see taxon-state)
logical; should progress be printed?
(character) required. you IUCN Redlist API key. See rredlist::rredlist-package for help on authenticating with IUCN Redlist
For get_iucn(): Deprecated, see sci. For as.iucn(), various,
see examples
Ignored
(logical) Check if ID matches any existing on the DB, only
used in as.iucn()
A vector of taxonomic identifiers as an S3 class.
Comes with the following attributes:
match (character) - the reason for NA, either 'not found',
'found' or if ask = FALSE then 'NA due to ask=FALSE')
name (character) - the taxonomic name, which is needed in
synonyms() and sci2comm() methods since they
internally use rredlist functions which require the taxonomic name,
and not the taxonomic identifier
ri (character) - The URI where more information can be read on the taxon - includes the taxonomic identifier in the URL somewhere
multiple_matches and pattern_match do not apply here as in other get_*
methods since there is no IUCN Redlist search, so you either get a match or
you do not get a match.
There is no underscore method, because there's no real search for IUCN, that is, where you search for a string, and get back a bunch of results due to fuzzy matching. If that exists in the future we'll add an underscore method here.
IUCN ids only work with synonyms() and sci2comm()
methods.
Other taxonomic-ids:
get_boldid(),
get_eolid(),
get_gbifid(),
get_ids(),
get_natservid(),
get_nbnid(),
get_pow(),
get_tolid(),
get_tpsid(),
get_tsn(),
get_uid(),
get_wiki(),
get_wormsid()
if (FALSE) { # \dontrun{
get_iucn("Branta canadensis")
get_iucn("Branta bernicla")
get_iucn("Panthera uncia")
} # }