# Search by scientific name, can abbreviate
itis("Plethodon", "searchbysci")
# Bet an LSID code from TSN code
itis(202420, 'getlsidfromtsn')
# Get the full taxonomic hierarchy for a taxon from the TSN
itis(36616, "getfullhierarchyfromtsn")
# Search by scientific name, then use a TSN to get its parent TSN
itis("Ursus", "searchbyscientificname") # let's pick one of the TSN's
itis(203539, "getparenttsnfromtsn")
itis(203539, "getsynonymnamesfromtsn") # no synonyms in this case
# Use multiple queries on one call to the function
itis(c(203539, 202420), "getsynonymnamesfromtsn")
# Use multiple ritis functions
itis(203539, c("getsynonymnamesfromtsn","getcommonnamesfromtsn"))
# Use multiple ritis functions and multiple queries
itis(c(203539, 202420), searchtype=c("getsynonymnamesfromtsn","getcommonnamesfromtsn"))Run the code above in your browser using DataLab