taxize-defunct: Defunct functions in taxize
Description
The following functions are now defunct (no longer available):Details
col_classification: Seeclassificationeol_hierarchy: Seeclassificationtp_classification: Seeclassificationtpl_search: Use theTaxonstandfunctionsTPLorTPLckdirectly.get_seqs: This function changed name toncbi_getbyname.get_genes: This function changed name toncbi_getbyid.get_genes_avail: This function changed name toncbi_search.ncbi_getbyname: Seencbi_bynamein thetraitspackage.ncbi_getbyid: Seencbi_byidin thetraitspackage.ncbi_search: Seencbi_searcherin thetraitspackage.eol_invasive: Seeeolin theoriginrpackage.gisd_isinvasive: Seegisdin theoriginrpackage.ubio_classification: The uBio web services was down for quite a while, is
now (as of 2016-05-09) back up, but we don't trust that it will stay up and available.ubio_classification_search: The uBio web services was down for quite
a while, is now (as of 2016-05-09) back up, but we don't trust that it will stay up
and available.ubio_id: The uBio web services was down for quite a while, is
now (as of 2016-05-09) back up, but we don't trust that it will stay up and available.ubio_ping: The uBio web services was down for quite a while, is
now (as of 2016-05-09) back up, but we don't trust that it will stay up and available.ubio_search: The uBio web services was down for quite a while, is
now (as of 2016-05-09) back up, but we don't trust that it will stay up and available.ubio_synonyms: The uBio web services was down for quite a while, is
now (as of 2016-05-09) back up, but we don't trust that it will stay up and available.get_ubioid: The uBio web services are apparently down indefinitely.phylomatic_tree: This function is defunct. Seephylomaticin the packagebrranchingphylomatic_format: This function is defunct. Seephylomatic_namesin the packagebrranching