Learn R Programming

taxize (version 0.3.0)

taxize-deprecated: Deprecated functions in taxize

Description

The following functions are now deprecated - see the function classification

Arguments

Details

The following functions have changed names. The old function names are still available to call, but simply return a message directing the user to the new function name.

In addition, tpl_search is deprecated - use the Taxonstand functions TPL or TPLck directly.