classificationcol_classification: This function is deprecated. Seeclassificationeol_hierarchy: This function is deprecated. Seeclassificationtp_classification: This function is deprecated. SeeclassificationThe following functions have changed names. The old function names are still available to call, but simply return a message directing the user to the new function name.
get_seqs: This function has changed name toncbi_getbyname.get_genes: This function has changed name toncbi_getbyid.get_genes_avail: This function has changed name toncbi_search.tp_acceptednames: This function has changed name totp_accnames.tp_namedistributions: This function has changed name totp_dist.tp_namereferences: This function has changed name totp_refs.itis_name: This function has changed name totax_name.In addition, tpl_search is deprecated - use the Taxonstand functions TPL or
TPLck directly.