The functions in the package that hit a specific API have a prefix and suffix
separated by an underscore. They follow the format of service_whatitdoes.
For example, gnr_resolve uses the Global Names Resolver API to resolve
species names.
General functions in the package that don't hit a specific API don't have
two words separated by an underscore, e.g., classification
You need API keys for Encyclopedia of Life (EOL), the Universal Biological Indexer and Organizer (uBio), Tropicos, and Plantminer.
If the source above has a TRUE in the SOAP? column, it is not available
in this package. They are available from a different package called taxizesoap.
See the GitHub repo for how to install