We are developing taxize as a package to allow users to search over many
websites for species names (scientific and common) and download up- and
downstream taxonomic hierarchical information - and many other things.The functions in the package that hit a specific API have a prefix and suffix
separated by an underscore. They follow the format of service_whatitdoes.
For example, gnr_resolve uses the Global Names Resolver API to resolve
species names.
General functions in the package that don't hit a specific API don't have
two words separated by an underscore, e.g., classification.
You need API keys for Encyclopedia of Life (EOL),
the Universal Biological Indexer and Organizer (uBio), Tropicos, and
Plantminer.
Currently supported APIs are:
ll{
API prefix
Encyclopedia of Life (EOL) eol_
Integrated Taxonomic Information Service (ITIS) itis_
Phylomatic phylomatic_
uBio ubio_
Global Names Resolver (from EOL/GBIF) gnr_
Global Names Index (from EOL/GBIF) gni_
IUCN Red List iucn_
Tropicos (from Missouri Botanical Garden) tp_
Plantminer plantminer_
Theplantlist.org tpl_
Catalogue of Life col_
Global Invasive Species Database gisd_
}